.. chandra_aca documentation master file, created by
   sphinx-quickstart on Fri Nov 13 15:19:28 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Quaternion
===========

.. toctree::
   :maxdepth: 2

   module
   quaternions

.. automodule:: Quaternion.Quaternion